@@ -36,13 +36,13 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
-use vars qw($VERSION $YAHOO_ASIA_URL);
+use vars qw( $YAHOO_ASIA_URL);
 
-$VERSION = '1.18';
+our $VERSION = '1.38'; # VERSION
 
 # URLs of where to obtain information.
 
-$YAHOO_ASIA_URL = ("http://sg.finance.yahoo.com/d/quotes.csv");
+$YAHOO_ASIA_URL = ("http://download.finance.yahoo.com/d/quotes.csv");
 
 sub methods {return (asia => \&yahoo_asia,yahoo_asia => \&yahoo_asia)};
 
